Test website

This is a test website for zimit/warc2zim.

Caution! Opening any of the subpages will likely activate all kind of trackers from the source websites

- All tests on a single page
- HTML5 audio tag
- HTML5 video tag
- Instagram
- Facebook video
- Facebook post
- Twitter post
- Twitter video
- Vimeo
- Youtube
- Twitch iframe
- Twitch JS embed
- Tiktok
- Dailymotion
- Spotify
- Soundcloud
- Medialement
- Broken inline CSS
- Broken CSS stylesheet
- Chinese encoding
- Bad encoding
- URL encoding
- Javascript
- Javascript with special chars
- HTTP return codes
- Base href
- onxxx HTML events
- links to folder instead of file
- Bad redirections
- Handling of content types
- Redirect with http-equiv meta directive
- Image with srcset
- Form GET
- Double Slash